<?xml version="1.0"?>
<!-- 
 Copyright 1999-2006 University of Chicago
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at
 
 http://www.apache.org/licenses/LICENSE-2.0
 
 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
-->
<xsl:stylesheet
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"

  xmlns:ag="http://mds.globus.org/aggregator/types"
  xmlns:wssg="http://docs.oasis-open.org/wsrf/2004/06/wsrf-WS-ServiceGroup-1.2-draft-01.xsd"
  xmlns:wsa="http://schemas.xmlsoap.org/ws/2004/03/addressing"
  xmlns:ns4="http://mds.globus.org/inmemoryservicegroup"
  xmlns:reg="http://www.globus.org/namespaces/2004/06/registry"
  version="1.0">
<xsl:import href="local/style.xsl" />
<xsl:import href="local/footer.xsl" />
<xsl:import href="xslfooter.xsl" />
<xsl:param name="requestInfo" select="''"/>
<xsl:param name="baseURI" select="''"/>
<xsl:param name="infoSource" select="''"/>
<xsl:variable name="baseID" select="translate('$Id: sg_servicetable.xsl,v 1.2.10.1 2007/05/17 20:57:41 pearlman Exp $', ':', '|')" />

<!-- match the RP document node -->
<xsl:template match="/*">

<html>
<head>
<title>Registered Services</title>
<style>
<xsl:call-template name="style" />
</style>
</head>
<body>


<h1>Registered Services</h1>

<table>

<xsl:apply-templates select="." mode="table-headings" />

 <xsl:apply-templates select=".//wssg:Entry" mode="rows">
   <xsl:sort select="wssg:MemberServiceEPR/wsa:Address" />
</xsl:apply-templates>
</table>

<xsl:call-template name="footer" />
<xsl:call-template name="xslFooter" />
</body>

</html>

</xsl:template>


<xsl:template 
    match="*"
    mode="table-headings">

<tr>
  <th>Resource Type</th>
  <th>Address</th>
  <th>Reference Properties</th>
  <th>Full EPR</th>
  <th>Details</th>
</tr>

</xsl:template>

<xsl:template 
    match="*"
    mode="rows">

<tr>
  <th><xsl:apply-templates select="." mode="servicetype" /></th>
  <td><xsl:value-of select="wssg:MemberServiceEPR/wsa:Address" /></td>
  <td> <xsl:apply-templates select="wssg:MemberServiceEPR/wsa:ReferenceProperties" mode="referenceproperties"/></td>
  <td><xsl:apply-templates mode="EPRLink" /></td>
  <td><xsl:apply-templates mode="DetailLink" /></td>
</tr>
</xsl:template>

<xsl:template mode="referenceproperties" match="*">
<xsl:for-each select="./@*">
 <xsl:value-of select="local-name()"/>=<xsl:value-of select="."/>
</xsl:for-each>
<xsl:for-each select="./child::node()[@* or text() or node()]">
  <xsl:call-template name="node"/>
</xsl:for-each>
</xsl:template>

<xsl:template name="node" match="*" mode="node">
 <xsl:value-of select="local-name()" />=<xsl:value-of select="text()"/>
<xsl:for-each select="@*">
 <xsl:value-of select="local-name()"/>=<xsl:value-of select="."/>
</xsl:for-each>
<xsl:for-each select="child::node()[@* or text() or node()]">
<xsl:call-template name="node"/>
</xsl:for-each>
</xsl:template>

<xsl:template mode="DetailLink" match="wssg:ServiceGroupEntryEPR[//ag:EntryKey]">
  <xsl:element name="a">
    <xsl:attribute name="href"><xsl:value-of select="$baseURI"/>&amp;xsl=sgedetailxsl&amp;xslParam.GroupKey=<xsl:value-of select="wsa:ReferenceProperties/ns4:ServiceGroupEntryKey/ag:GroupKey"/>&amp;xslParam.EntryKey=<xsl:value-of select="wsa:ReferenceProperties/ns4:ServiceGroupEntryKey/ag:EntryKey"/></xsl:attribute>
      <xsl:text>Details</xsl:text>
  </xsl:element>

</xsl:template>

<xsl:template mode="DetailLink" match="*" priority="-10" />


<xsl:template mode="EPRLink" match="wssg:ServiceGroupEntryEPR[//ag:EntryKey]">
  <xsl:element name="a">
    <xsl:attribute name="href"><xsl:value-of select="$baseURI"/>&amp;xmlSource.<xsl:value-of select="$infoSource"/>.param.xpathQuery=//ns1:Entry[*/*/*/ns5:GroupKey=<xsl:value-of select="wsa:ReferenceProperties/ns4:ServiceGroupEntryKey/ag:GroupKey"/> and */*/*/ns5:EntryKey=<xsl:value-of select="wsa:ReferenceProperties/ns4:ServiceGroupEntryKey/ag:EntryKey"/>]/ns1:MemberServiceEPR</xsl:attribute>
      <xsl:text>Full EPR</xsl:text>
  </xsl:element>
</xsl:template>

<xsl:template mode="EPRLink" match="*" priority="-10" />


<xsl:template match="wssg:Entry[wssg:Content/ag:AggregatorData/glue:GLUECE]" 
              mode="servicetype" 
	      priority="100"
              xmlns:glue="http://mds.globus.org/glue/ce/1.1">
GRAM
</xsl:template>

<xsl:template match="wssg:Entry[wssg:Content/ag:AggregatorConfig//ag:ResourcePropertyName/text()='glue:GLUECE']" 
              mode="servicetype" 
	      priority="10"
              xmlns:glue="http://mds.globus.org/glue/ce/1.1">
GRAM
</xsl:template>

<xsl:template match="wssg:Entry[wssg:Content/ag:AggregatorConfig//ag:ResourcePropertyNames/text()='glue:GLUECE']" 
              mode="servicetype" 
	      priority="10"
              xmlns:glue="http://mds.globus.org/glue/ce/1.1">
GRAM
</xsl:template>

<xsl:template match="wssg:Entry[wssg:Content/ag:AggregatorData/gridftp:connections_max]" 
              mode="servicetype" 
	      priority="100"
              xmlns:gridftp="http://www.globus.org/namespaces/2005/09/GridFTPAdmin">
GridFTP
</xsl:template>


<xsl:template match="wssg:Entry[wssg:Content/ag:AggregatorConfig//ag:ResourcePropertyName/text()='gridftp:connections']" 
              mode="servicetype" 
	      priority="10"
              xmlns:gridftp="http://www.globus.org/namespaces/2005/09/GridFTPAdmin">
GridFTP
</xsl:template>

<xsl:template match="wssg:Entry[wssg:Content/ag:AggregatorConfig//ag:ResourcePropertyNames/text()='gridftp:connections']" 
              mode="servicetype" 
	      priority="10"
              xmlns:gridftp="http://www.globus.org/namespaces/2005/09/GridFTPAdmin">
GridFTP
</xsl:template>


<xsl:template match="wssg:Entry[wssg:Content/ag:AggregatorData/rlsStats]" 
              mode="servicetype" 
	      priority="100"
              xmlns:rft="http://www.globus.org/namespaces/2004/10/rft">
RLS
</xsl:template>

<xsl:template match="wssg:Entry[wssg:Content/ag:AggregatorData/cas:VoDescription]" 
              mode="servicetype" 
	      priority="100"
              xmlns:cas="http://www.globus.org/07/2004/cas">
CAS
</xsl:template>

<xsl:template match="wssg:Entry[wssg:Content/ag:AggregatorData/rft:ActiveResourceInstances]" 
              mode="servicetype" 
	      priority="100"
              xmlns:rft="http://www.globus.org/namespaces/2004/10/rft">
RFT
</xsl:template>

<xsl:template match="wssg:Entry[wssg:Content/ag:AggregatorConfig//ag:ResourcePropertyNames/text()='rft:ActiveResourceInstances']" 
              mode="servicetype" 
	      priority="10"
              xmlns:rft="http://www.globus.org/namespaces/2004/10/rft">
RFT
</xsl:template>

<xsl:template match="wssg:Entry[wssg:Content/ag:AggregatorConfig//ag:ResourcePropertyName/text()='rft:ActiveResourceInstances']" 
              mode="servicetype" 
	      priority="10"
              xmlns:rft="http://www.globus.org/namespaces/2004/10/rft">
RFT
</xsl:template>

<xsl:template match="wssg:Entry[wssg:Content/ag:AggregatorData/wssg:Entry]" 
	      priority="100"
              mode="servicetype" >
WS-MDS Index
</xsl:template>

<xsl:template match="wssg:Entry[wssg:Content/ag:AggregatorConfig//ag:ResourcePropertyName/text()='wssg:Entry']" 
              mode="servicetype" 
	      priority="10">
WS-MDS Index
</xsl:template>

<xsl:template match="wssg:Entry[wssg:Content/ag:AggregatorConfig//ag:ResourcePropertyNames/text()='wssg:Entry']" 
              mode="servicetype" 
	      priority="10">
WS-MDS Index
</xsl:template>

<xsl:template match="*" 
              priority="-10"
              mode="servicetype">
Unknown
</xsl:template>

</xsl:stylesheet>
